@@ -6,34 +6,34 @@ import configparser
 import logging
 import os
 from configparser import ConfigParser
+from contextlib import contextmanager
 from functools import partial, wraps
 
 import component_registry_bindings
 import osidb_bindings
 from osidb_bindings.bindings.python_client.models import Affect, Flaw, Tracker
-from pkg_resources import resource_filename  # type: ignore
+from pkg_resources import resource_filename
 from rich.logging import RichHandler
 
+from griffon.helpers import Color, Style
 from griffon.output import console
 
-__version__ = "0.3.7"
+__version__ = "0.5.2"
 
-if "CORGI_API_URL" not in os.environ:
-    print("Must set CORGI_API_URL environment variable.")
-    exit(1)
-CORGI_API_URL = os.environ["CORGI_API_URL"]
+# TODO: Deprecate CORGI_API_URL completely in the next version or two
+CORGI_SERVER_URL = os.getenv("CORGI_SERVER_URL", os.getenv("CORGI_API_URL"))
+# TODO: Deprecate OSIDB_API_URL completely in the next version or two
+OSIDB_SERVER_URL = os.getenv("OSIDB_SERVER_URL", os.getenv("OSIDB_API_URL"))
 
-if "OSIDB_API_URL" not in os.environ:
-    print("Must set OSIDB_API_URL environment variable.")
-    exit(1)
-OSIDB_API_URL = os.environ["OSIDB_API_URL"]
 OSIDB_USERNAME = os.getenv("OSIDB_USERNAME", "")
 OSIDB_PASSWORD = os.getenv("OSIDB_PASSWORD", "")
 OSIDB_AUTH_METHOD = os.getenv("OSIDB_AUTH_METHOD", "kerberos")
 
+# TODO: Deprecate COMMUNITY_COMPONENTS_API_URL completely in the next version or two
 # required to enable --search-community
-COMMUNITY_COMPONENTS_API_URL = os.getenv(
-    "COMMUNITY_COMPONENTS_API_URL", "https://component-registry.fedoraproject.org"
+COMMUNITY_COMPONENTS_SERVER_URL = os.getenv(
+    "COMMUNITY_COMPONENTS_SERVER_URL",
+    os.getenv("COMMUNITY_COMPONENTS_API_URL", "https://component-registry.fedoraproject.org"),
 )
 
 # TODO: temporary hack required to enable searching of middleware
@@ -42,20 +42,59 @@ MIDDLEWARE_CLI = os.getenv("GRIFFON_MIDDLEWARE_CLI")
 GRIFFON_CONFIG_DIR = os.getenv("GRIFFON_API_URL", "~/.griffon")
 GRIFFON_RC_FILE = "~/.griffonrc"
 GRIFFON_DEFAULT_LOG_FILE = os.getenv("GRIFFON_DEFAULT_LOG_FILE", "~/.griffon/history.log")
+GRIFFON_VERIFY_SSL = os.getenv("GRIFFON_VERIFY_SSL", "True").lower() in ("true", "1", "t")
 
 logger = logging.getLogger("griffon")
 
 RELATED_MODELS_MAPPING = {Flaw: {"affects": Affect}, Affect: {"trackers": Tracker}}
 
 
+def check_envvars():
+    """Check that all necessary envvars are set"""
+
+    # TODO: Deprecate CORGI_API_URL completely in the next version or two
+    if "CORGI_API_URL" in os.environ:
+        print(
+            (
+                f"{Style.BOLD}{Color.YELLOW}WARNING: CORGI_API_URL will be deprecated "
+                "in the next version of Griffon in favour of CORGI_SERVER_URL, please "
+                f"switch to the new environment variable.{Style.RESET}"
+            )
+        )
+    if "CORGI_SERVER_URL" not in os.environ and "CORGI_API_URL" not in os.environ:
+        print("Must set CORGI_SERVER_URL environment variable.")
+        exit(1)
+
+    # TODO: Deprecate COMMUNITY_COMPONENTS_API_URL completely in the next version or two
+    if "COMMUNITY_COMPONENTS_API_URL" in os.environ:
+        print(
+            (
+                f"{Style.BOLD}{Color.YELLOW}WARNING: COMMUNITY_COMPONENTS_API_URL "
+                "will be deprecated in the next version of Griffon in favour of "
+                "COMMUNITY_COMPONENTS_SERVER_URL, please switch to the new environment "
+                f"variable.{Style.RESET}"
+            )
+        )
+
+    # TODO: Deprecate OSIDB_API_URL completely in the next version or two
+    if "OSIDB_API_URL" in os.environ:
+        print(
+            (
+                f"{Style.BOLD}{Color.YELLOW}WARNING: OSIDB_API_URL will be deprecated "
+                "in the next version of Griffon in favour of OSIDB_SERVER_URL, please "
+                f"switch to the new environment variable.{Style.RESET}"
+            )
+        )
+    if "OSIDB_SERVER_URL" not in os.environ and "OSIDB_API_URL" not in os.environ:
+        print("Must set OSIDB_SERVER_URL environment variable.")
+        exit(1)
+
+
 def config_logging(level="INFO"):
     # if set to 'DEBUG' then we want all the http conversation
     if level == "DEBUG":
-        try:
-            import http.client as http_client
-        except ImportError:
-            # Python 2
-            import httplib as http_client
+        import http.client as http_client
+
         http_client.HTTPConnection.debuglevel = 1
 
     message_format = "%(asctime)s %(name)s %(levelname)s %(message)s"
@@ -99,10 +138,11 @@ class CorgiService:
         """init corgi session"""
         try:
             return component_registry_bindings.new_session(
-                component_registry_server_uri=CORGI_API_URL,
+                component_registry_server_uri=CORGI_SERVER_URL,
+                verify_ssl=GRIFFON_VERIFY_SSL,
             )
         except:  # noqa
-            console.log(f"{CORGI_API_URL} is not accessible.")
+            console.log(f"{CORGI_SERVER_URL} is not accessible.")
             exit(1)
 
     @staticmethod
@@ -166,9 +206,13 @@ class OSIDBService:
             if OSIDB_AUTH_METHOD == "credentials":
                 credentials["username"] = OSIDB_USERNAME
                 credentials["password"] = OSIDB_PASSWORD
-            return osidb_bindings.new_session(osidb_server_uri=OSIDB_API_URL, **credentials)
+            return osidb_bindings.new_session(
+                osidb_server_uri=OSIDB_SERVER_URL,
+                verify_ssl=GRIFFON_VERIFY_SSL,
+                **credentials,
+            )
         except:  # noqa
-            console.log(f"{OSIDB_API_URL} is not accessible (or krb ticket has expired).")
+            console.log(f"{OSIDB_SERVER_URL} is not accessible (or krb ticket has expired).")
             exit(1)
 
     @staticmethod
@@ -268,10 +312,11 @@ class CommunityComponentService:
         """init corgi session"""
         try:
             return component_registry_bindings.new_session(
-                component_registry_server_uri=COMMUNITY_COMPONENTS_API_URL,
+                component_registry_server_uri=COMMUNITY_COMPONENTS_SERVER_URL,
+                verify_ssl=GRIFFON_VERIFY_SSL,
             )
         except:  # noqa
-            console.log(f"{COMMUNITY_COMPONENTS_API_URL} is not accessible.")
+            console.log(f"{COMMUNITY_COMPONENTS_SERVER_URL } is not accessible.")
             exit(1)
 
     @staticmethod
@@ -322,7 +367,79 @@ class CommunityComponentService:
         return fields
 
 
-def progress_bar(
+@contextmanager
+def console_status(no_progress_bar, initial_status=None):
+    """updatable console status progress bar"""
+
+    class DisabledStatusObject:
+        """
+        Dummy disabled status object for graceful handle of
+        no progress bar option
+        """
+
+        def __getattr__(self, attr):
+            def dummy_method(*args, **kwargs):
+                pass  # Do nothing when any method is called
+
+            return dummy_method
+
+    class StatusObject:
+        """
+        Status object for default Griffon status handling
+        """
+
+        def __init__(self, status):
+            self.status = status
+
+        def update(self, status, *args, **kwargs):
+            self.status.update(
+                status=f"[magenta b]griffoning:[/magenta b] [bold]{status}[/bold]", *args, **kwargs
+            )
+
+        def start(self):
+            self.status.start()
+
+        def stop(self):
+            self.status.stop()
+
+    if no_progress_bar:
+        yield DisabledStatusObject()
+    else:
+        status = f": {initial_status}" if initial_status else ""
+
+        with console.status(
+            f"[magenta b]griffoning[/magenta b]{status}", spinner="line"
+        ) as operation_status:
+            yield StatusObject(operation_status)
+
+
+def progress_bar(is_updatable=False, initial_status=None):
+    """
+    progress bar decorator
+
+    :param updatable: allows/disallows updatable progress bar status, if set to `True`
+    decorated function needs to have `operation_status` parameter
+    """
+
+    def decorator(func=None):
+        if not func:
+            return partial(decorator)
+
+        @wraps(func)
+        def wrapper(*args, **kwargs):
+            obj: dict = args[0].obj
+            with console_status(obj.get("NO_PROGRESS_BAR"), initial_status) as operation_status:
+                if is_updatable:
+                    func(*args, operation_status=operation_status, **kwargs)
+                else:
+                    func(*args, **kwargs)
+
+        return wrapper
+
+    return decorator
+
+
+def progress_bar2(
     func=None,
 ):
     """progress bar decorator"""
@@ -332,11 +449,8 @@ def progress_bar(
     @wraps(func)
     def wrapper(*args, **kwargs):
         obj: dict = args[0].obj
-        if obj.get("NO_PROGRESS_BAR"):
-            func(*args, **kwargs)
-        else:
-            with console.status("griffoning", spinner="line"):
-                func(*args, **kwargs)
+        with console_status(obj.get("NO_PROGRESS_BAR")) as operation_status:
+            func(*args, operation_status=operation_status, **kwargs)
 
     return wrapper
 
