@@ -33,8 +33,8 @@ from component_registry_bindings.bindings.python_client.models import (
 )
 
 from griffon import (
-    COMMUNITY_COMPONENTS_API_URL,
-    CORGI_API_URL,
+    COMMUNITY_COMPONENTS_SERVER_URL,
+    CORGI_SERVER_URL,
     CommunityComponentService,
     progress_bar,
 )
@@ -48,6 +48,7 @@ from griffon.commands.entities.helpers import (
     multivalue_params_to_csv,
     query_params_options,
 )
+from griffon.exceptions import GriffonException
 from griffon.output import console, cprint
 
 logger = logging.getLogger("griffon")
@@ -64,7 +65,7 @@ def commmunity_components_grp(ctx):
 # COMPONENTS
 
 
-@commmunity_components_grp.group(help=f"{COMMUNITY_COMPONENTS_API_URL}/api/v1/components")
+@commmunity_components_grp.group(help=f"{COMMUNITY_COMPONENTS_SERVER_URL}/api/v1/components")
 @click.pass_context
 def components(ctx):
     """Corgi Components."""
@@ -87,7 +88,7 @@ def components(ctx):
     },
 )
 @click.pass_context
-@progress_bar
+@progress_bar()
 def list_components(ctx, strict_name_search, component_name, **params):
     is_params_empty = [False for v in params.values() if v]
     if not component_name and not is_params_empty:
@@ -120,7 +121,7 @@ def list_components(ctx, strict_name_search, component_name, **params):
     },
 )
 @click.pass_context
-@progress_bar
+@progress_bar()
 def get_component(ctx, component_id, purl, **params):
     is_params_empty = [False for v in params.values() if v]
     if not component_id and not purl and not is_params_empty:
@@ -168,7 +169,7 @@ def get_component(ctx, component_id, purl, **params):
     },
 )
 @click.pass_context
-@progress_bar
+@progress_bar()
 def get_component_summary(ctx, component_name, strict_name_search, **params):
     """Get Component summary."""
     is_params_empty = [False for v in params.values() if v]
@@ -203,7 +204,7 @@ def get_component_summary(ctx, component_name, strict_name_search, **params):
         for ps in component.product_streams:
             product_streams.append(ps["name"])
     data = {
-        "link": f"{CORGI_API_URL}/api/v1/components?name={component_name}",
+        "link": f"{CORGI_SERVER_URL}/api/v1/components?name={component_name}",
         "type": component_type,
         "name": component_name,
         "tags": sorted(list(set(tags))),
@@ -230,7 +231,7 @@ def get_component_summary(ctx, component_name, strict_name_search, **params):
     },
 )
 @click.pass_context
-@progress_bar
+@progress_bar()
 def get_component_provides(ctx, component_uuid, purl, **params):
     """Retrieve all Components provided by a Component."""
     is_params_empty = [False for v in params.values() if v]
@@ -270,7 +271,7 @@ def get_component_provides(ctx, component_uuid, purl, **params):
     },
 )
 @click.pass_context
-@progress_bar
+@progress_bar()
 def get_component_sources(ctx, component_uuid, purl, **params):
     """Retrieve all Components that contain Component."""
     is_params_empty = [False for v in params.values() if v]
@@ -309,7 +310,7 @@ def get_component_sources(ctx, component_uuid, purl, **params):
     help="Generate spdx manifest (json).",
 )
 @click.pass_context
-@progress_bar
+@progress_bar()
 def get_component_manifest(ctx, component_uuid, purl, spdx_json_format):
     """Retrieve Component manifest."""
     if not component_uuid and not purl:
@@ -330,7 +331,7 @@ def get_component_manifest(ctx, component_uuid, purl, spdx_json_format):
 
 
 # PRODUCT STREAM
-@commmunity_components_grp.group(help=f"{CORGI_API_URL}/api/v1/product_streams")
+@commmunity_components_grp.group(help=f"{CORGI_SERVER_URL}/api/v1/product_streams")
 @click.pass_context
 def product_streams(ctx):
     pass
@@ -390,7 +391,7 @@ def list_product_streams(ctx, product_stream_name, **params):
     },
 )
 @click.pass_context
-@progress_bar
+@progress_bar()
 def get_product_stream(ctx, product_stream_name, inactive, ofuri, **params):
     """Retrieve Product Stream."""
     is_params_empty = [False for v in params.values() if v]
@@ -422,7 +423,8 @@ def get_product_stream(ctx, product_stream_name, inactive, ofuri, **params):
     },
 )
 @click.pass_context
-def get_product_stream_components(ctx, product_stream_name, ofuri, **params):
+@progress_bar(is_updatable=True)
+def get_product_stream_components(ctx, product_stream_name, ofuri, operation_status, **params):
     """Retrieve Product Stream latest Components."""
     if not ofuri and not product_stream_name:
         click.echo(ctx.get_help())
@@ -438,6 +440,8 @@ def get_product_stream_components(ctx, product_stream_name, ofuri, **params):
         params["ofuri"] = ps["ofuri"]
     if ofuri:
         params["ofuri"] = ofuri
+
+    operation_status.stop()
     ctx.invoke(list_components, **params)
 
 
@@ -457,7 +461,7 @@ def get_product_stream_components(ctx, product_stream_name, ofuri, **params):
     help="Generate spdx manifest (json).",
 )
 @click.pass_context
-@progress_bar
+@progress_bar()
 def get_product_stream_manifest(ctx, product_stream_name, ofuri, spdx_json_format):
     """Retrieve Product Stream manifest."""
     if not ofuri and not product_stream_name:
@@ -481,7 +485,7 @@ def get_product_stream_manifest(ctx, product_stream_name, ofuri, spdx_json_forma
 # BUILDS
 
 
-@commmunity_components_grp.group(help=f"{CORGI_API_URL}/api/v1/builds")
+@commmunity_components_grp.group(help=f"{CORGI_SERVER_URL}/api/v1/builds")
 @click.pass_context
 def builds(ctx):
     pass
@@ -526,7 +530,7 @@ def list_software_builds(ctx, software_build_name, **params):
     },
 )
 @click.pass_context
-@progress_bar
+@progress_bar()
 def get_software_build(ctx, software_build_name, **params):
     """Retrieve SoftwareBuild."""
     is_params_empty = [False for v in params.values() if v]
@@ -543,7 +547,7 @@ def get_software_build(ctx, software_build_name, **params):
 # Products
 
 
-@commmunity_components_grp.group(help=f"{CORGI_API_URL}/api/v1/products")
+@commmunity_components_grp.group(help=f"{CORGI_SERVER_URL}/api/v1/products")
 @click.pass_context
 def products(ctx):
     pass
@@ -559,7 +563,7 @@ def products(ctx):
     },
 )
 @click.pass_context
-@progress_bar
+@progress_bar()
 def list_products(ctx, product_name, **params):
     """Retrieve a list of Software Builds."""
     session = CommunityComponentService.create_session()
@@ -586,7 +590,7 @@ def list_products(ctx, product_name, **params):
     },
 )
 @click.pass_context
-@progress_bar
+@progress_bar()
 def get_product(ctx, product_name, ofuri, **params):
     """Retrieve Product."""
     is_params_empty = [False for v in params.values() if v]
@@ -603,7 +607,7 @@ def get_product(ctx, product_name, ofuri, **params):
 
 
 # PRODUCT VERSION
-@commmunity_components_grp.group(help=f"{CORGI_API_URL}/api/v1/product-versions")
+@commmunity_components_grp.group(help=f"{CORGI_SERVER_URL}/api/v1/product-versions")
 @click.pass_context
 def product_versions(ctx):
     pass
@@ -621,7 +625,7 @@ def product_versions(ctx):
     },
 )
 @click.pass_context
-@progress_bar
+@progress_bar()
 def list_product_versions(ctx, product_version_name, **params):
     """Retrieve a list of Product Versions."""
     session = CommunityComponentService.create_session()
@@ -651,7 +655,7 @@ def list_product_versions(ctx, product_version_name, **params):
     },
 )
 @click.pass_context
-@progress_bar
+@progress_bar()
 def get_product_version(ctx, product_version_name, ofuri, **params):
     """Retrieve ProductVersion."""
     is_params_empty = [False for v in params.values() if v]
@@ -668,7 +672,7 @@ def get_product_version(ctx, product_version_name, ofuri, **params):
 
 
 # PRODUCT VARIANT
-@commmunity_components_grp.group(help=f"{CORGI_API_URL}/api/v1/product-variants")
+@commmunity_components_grp.group(help=f"{CORGI_SERVER_URL}/api/v1/product-variants")
 @click.pass_context
 def product_variants(ctx):
     pass
@@ -686,7 +690,7 @@ def product_variants(ctx):
     },
 )
 @click.pass_context
-@progress_bar
+@progress_bar()
 def list_product_variants(ctx, product_variant_name, **params):
     """Retrieve a list of Product Variants."""
     session = CommunityComponentService.create_session()
@@ -716,7 +720,7 @@ def list_product_variants(ctx, product_variant_name, **params):
     },
 )
 @click.pass_context
-@progress_bar
+@progress_bar()
 def get_product_variant(ctx, product_variant_name, ofuri, **params):
     """Retrieve ProductVariant."""
     is_params_empty = [False for v in params.values() if v]
@@ -733,7 +737,7 @@ def get_product_variant(ctx, product_variant_name, ofuri, **params):
 
 
 # CHANNEL
-@commmunity_components_grp.group(help=f"{CORGI_API_URL}/api/v1/channels")
+@commmunity_components_grp.group(help=f"{CORGI_SERVER_URL}/api/v1/channels")
 @click.pass_context
 def channels(ctx):
     pass
@@ -749,7 +753,7 @@ def channels(ctx):
     },
 )
 @click.pass_context
-@progress_bar
+@progress_bar()
 def list_channels(ctx, channel_name, **params):
     """Retrieve a list of Channels."""
     session = CommunityComponentService.create_session()
@@ -776,7 +780,7 @@ def list_channels(ctx, channel_name, **params):
     },
 )
 @click.pass_context
-@progress_bar
+@progress_bar()
 def get_channel(ctx, channel_name, ofuri, **params):
     """Retrieve ProductVariant."""
     is_params_empty = [False for v in params.values() if v]
@@ -815,20 +819,20 @@ def corgi_health(ctx):
         session = CommunityComponentService.create_session()
         status = session.status()["status"]
         if status == "ok":
-            console.log(f"{CORGI_API_URL} is operational")
+            console.log(f"{CORGI_SERVER_URL} is operational")
         else:
-            console.log(f"{CORGI_API_URL} is NOT operational")
+            console.log(f"{CORGI_SERVER_URL} is NOT operational")
             exit(1)
     except:  # noqa
-        console.log(f"{CORGI_API_URL} is NOT operational")
-        raise click.ClickException("Component registry health check failed.")
+        console.log(f"{CORGI_SERVER_URL} is NOT operational")
+        raise GriffonException("Component registry health check failed.")
 
 
 @manage_grp.command(name="data")
 def corgi_data():
-    click.launch(f"{CORGI_API_URL}/data")
+    click.launch(f"{CORGI_SERVER_URL}/data")
 
 
 @manage_grp.command(name="api_doc")
 def corgi_api_docs():
-    click.launch(f"{CORGI_API_URL}/api/v1/schema/docs")
+    click.launch(f"{CORGI_SERVER_URL}/api/v1/schema/docs")
