@@ -40,9 +40,17 @@ def reports_grp(ctx):
 @click.option("--product-name", shell_complete=get_product_stream_names)
 @click.option("--ofuri", shell_complete=get_product_stream_ofuris)
 @click.pass_context
-@progress_bar
+@progress_bar()
 def generate_affects_report(
-    ctx, product_version_name, all, show_components, show_products, purl, name, product_name, ofuri
+    ctx,
+    product_version_name,
+    all,
+    show_components,
+    show_products,
+    purl,
+    name,
+    product_name,
+    ofuri,
 ):
     """A report operation"""
     if not all and not product_version_name:
@@ -54,7 +62,7 @@ def generate_affects_report(
 @reports_grp.command(name="report-entities", help="Generate Entity report (with counts).")
 @click.option("--all", is_flag=True, default=True, help="Show summary report on all entities.")
 @click.pass_context
-@progress_bar
+@progress_bar()
 def generate_entity_report(ctx, all):
     """A report operation"""
     if not all:
@@ -75,7 +83,7 @@ def generate_entity_report(ctx, all):
     "--exclude_children", is_flag=True, default=False, help="Exclude children Component licenses."
 )
 @click.pass_context
-@progress_bar
+@progress_bar()
 def generate_license_report(ctx, product_stream_name, purl, exclude_children):
     """A report operation"""
     if not product_stream_name and not purl:
